@@ -1,9 +1,13 @@
 from collections import OrderedDict
+from pathlib import Path
 from types import FunctionType
-from typing import Any, Dict, Set
+from typing import Any, Dict, Set, Union
 
 from .exceptions import Error, Extra, Missing, ValidationError
 from .fields import Field
+from .parse import Protocol, load_file, load_str_bytes
+from .types import StrBytes
+from .utils import truncate
 from .validators import dict_validator
 
 
@@ -44,26 +48,18 @@ class MetaModel(type):
                 fields.update(base.__fields__)
                 config = inherit_config(base.config, config)
 
-        annotations = namespace.get('__annotations__')
         config = inherit_config(namespace.get('Config'), config)
-        class_validators = {n: f for n, f in namespace.items()
-                            if n.startswith('validate_') and isinstance(f, FunctionType)}
+        class_validators = {
+            n: f for n, f in namespace.items() if n.startswith('validate_') and isinstance(f, FunctionType)
+        }
 
-        for var_name, value in namespace.items():
-            if var_name.startswith('_') or isinstance(value, TYPE_BLACKLIST):
-                continue
-            fields[var_name] = Field.infer(
-                name=var_name,
-                value=value,
-                annotation=annotations.pop(var_name, None) if annotations else None,
-                class_validators=class_validators,
-                config=config,
-            )
+        for f in fields.values():
+            f.set_config(config)
 
-        if annotations:
-            for ann_name, ann_type in annotations.items():
-                if ann_name.startswith('_'):
-                    continue
+        annotations = namespace.get('__annotations__', {})
+        # annotation only fields need to come first in fields
+        for ann_name, ann_type in annotations.items():
+            if not ann_name.startswith('_') and ann_name not in namespace:
                 fields[ann_name] = Field.infer(
                     name=ann_name,
                     value=...,
@@ -72,6 +68,16 @@ class MetaModel(type):
                     config=config,
                 )
 
+        for var_name, value in namespace.items():
+            if not var_name.startswith('_') and not isinstance(value, TYPE_BLACKLIST):
+                fields[var_name] = Field.infer(
+                    name=var_name,
+                    value=value,
+                    annotation=annotations.get(var_name),
+                    class_validators=class_validators,
+                    config=config,
+                )
+
         new_namespace = {
             'config': config,
             '__fields__': fields,
@@ -124,11 +130,40 @@ class BaseModel(metaclass=MetaModel):
             if k not in exclude and (not include or k in include)
         }
 
+    @classmethod
+    def parse_obj(cls, obj):
+        if not isinstance(obj, dict):
+            exc = TypeError(f'{cls.__name__} expected dict not {type(obj).__name__}')
+            raise ValidationError([Error(exc, None, None)])
+        return cls(**obj)
+
+    @classmethod
+    def parse_raw(cls, b: StrBytes, *,
+                  content_type: str=None,
+                  encoding: str='utf8',
+                  proto: Protocol=None,
+                  allow_pickle: bool=False):
+        try:
+            obj = load_str_bytes(b, proto=proto, content_type=content_type, encoding=encoding,
+                                 allow_pickle=allow_pickle)
+        except (ValueError, TypeError, UnicodeDecodeError) as e:
+            raise ValidationError([Error(e, None, None)])
+        return cls.parse_obj(obj)
+
+    @classmethod
+    def parse_file(cls, path: Union[str, Path], *,
+                   content_type: str=None,
+                   encoding: str='utf8',
+                   proto: Protocol=None,
+                   allow_pickle: bool=False):
+        obj = load_file(path, proto=proto, content_type=content_type, encoding=encoding, allow_pickle=allow_pickle)
+        return cls.parse_obj(obj)
+
     @classmethod
     def construct(cls, **values):
         """
-        Creates a new model and set __values__ without any validation, thus values should be trusted
-        data. Chances are you don't want to use this method directly.
+        Creates a new model and set __values__ without any validation, thus values should already be trusted.
+        Chances are you don't want to use this method directly.
         """
         m = cls.__new__(cls)
         m.__setstate__(values)
@@ -168,7 +203,7 @@ class BaseModel(metaclass=MetaModel):
     def validate(cls, value):
         return cls(**value)
 
-    def _process_values(self, input_data: dict) -> OrderedDict:  # noqa: C901
+    def _process_values(self, input_data: dict) -> OrderedDict:  # noqa: C901 (ignore complexity)
         values = OrderedDict()
         errors = OrderedDict()
 
@@ -219,7 +254,9 @@ class BaseModel(metaclass=MetaModel):
             return v
 
     def __iter__(self):
-        # so `dict(model)` works
+        """
+        so `dict(model)` works
+        """
         for k, v in self.__values__.items():
             yield k, self._get_value(v)
 
@@ -232,23 +269,12 @@ class BaseModel(metaclass=MetaModel):
     def __repr__(self):
         return f'<{self}>'
 
-    @classmethod
-    def _truncate(cls, v):
-        max_len = 80
-        if isinstance(v, str) and len(v) > (max_len - 2):
-            # 45 so quote + string + ... + quote has length 50
-            return repr(v[:(max_len - 5)] + '...')
-        v = repr(v)
-        if len(v) > max_len:
-            v = v[:max_len - 3] + '...'
-        return v
-
     def to_string(self, pretty=False):
         divider = '\n  ' if pretty else ' '
         return '{}{}{}'.format(
             self.__class__.__name__,
             divider,
-            divider.join('{}={}'.format(k, self._truncate(v)) for k, v in self.__values__.items()),
+            divider.join('{}={}'.format(k, truncate(v)) for k, v in self.__values__.items()),
         )
 
     def __str__(self):
